<?php
class AgregarcitaF_model extends CI_Model { 
   //En este modelo se encuentran todas las consultas que se harán en diferentes tablas(Franquiciatario)
   public function __construct() {
      parent::__construct();
   }


    //Consulta que busca los clientes registrados en la franquicia a la que pertenece el ususario logueado
    public function BuscarCliente($title){
    $data['Franquicias']=$this->agregarcitaF_model->BuscarFranquicia();
    foreach ($data['Franquicias'] as $i => $Franquicias) 
       $this->db->select('*');
       $this->db->where('Franquicias_IdFranquicias',$i);
       $this->db->like('NombreCliente',$title);
       $this->db->order_by('NombreCliente','ASC');
       return $this->db->get('clientes')->result();
      
         }


         //Consulta que busca los servicios registrados en la franquicia a la que pertenece el ususario logueado
    public function BuscarServicio($servicio){
    $data['Franquicias']=$this->agregarcitaF_model->BuscarFranquicia();
    foreach ($data['Franquicias'] as $i => $Franquicias)
        $this->db->select('*');
        $this->db->from('serviciosfranquicias');
        $this->db->join('serviciosgenerales','ServiciosGenerales_IdServiciosGenerales=IdServiciosGenerales','inner');
        $this->db->where('Franquicias_IdFranquicias',$i);
        $this->db->like('NombreServicio',$servicio);
        $this->db->order_by('NombreServicio','ASC');
        return $this->db->get()->result();
         }

 public function BuscarServicioG($servicioG){
    $data['Zona']=$this->agregarcitaF_model->BuscarZona();
    foreach ($data['Zona'] as $i => $Zona) 
    $data['Modelo']=$this->agregarcitaF_model->BuscarModelo();
    foreach ($data['Modelo'] as $j => $Modelo)

         $this->db->select('*');
         $this->db->from('serviciosgenerales');
         $this->db->where('Zona_IdZona',$i);
         $this->db->where('Modelo_IdModelo',$j);
        $this->db->WHERE("(TipoServicio_IdTipoServicio = '2' OR TipoServicio_IdTipoServicio = '3')");
        $this->db->like('NombreServicio',$servicioG);
        $this->db->order_by('NombreServicio','ASC');
        return $this->db->get()->result();

         }
//Busca promocion Institucional
    public function BuscarPromociones($promocion){
    $data['Zona']=$this->agregarcitaF_model->BuscarZona();
    foreach ($data['Zona'] as $i => $Zona) 
    $this->db->where('Zona_IdZona',$i);
    $this->db->where("(tipopromocion_IdTipoPromocion = '1' OR tipopromocion_IdTipoPromocion ='3')");
    $this->db->where('Estatus','ACTIVA');
    $this->db->where('ClasePromocion','Servicio');
    $this->db->like('NombrePromocion',$promocion);
    $this->db->order_by('NombrePromocion',"ASC");
    return $this->db->get('promociones')->result();

    }

//Busca Promociones Franquicias
         //Consulta que busca las promociones registradas en la franquicia a la que pertenece el ususario logueado
    public function BuscarPromocion($promocion){
        $data['Franquicias']=$this->agregarcitaF_model->BuscarFranquicia();
        foreach ($data['Franquicias'] as $i => $Franquicias)
        // $data['Zona']=$this->agregarcitaF_model->BuscarZona();
        // foreach ($data['Zona'] as $a => $Zona) 
        // $this->db->where("(Zona_IdZona= '".$a."' AND Franquicias_IdFranquicias = '".$i."')");
        $this->db->where('Franquicias_IdFranquicias',$i);
        $this->db->where('Estatus','ACTIVA');
        $this->db->like('NombrePromocion',$promocion);
        $this->db->order_by('NombrePromocion',"ASC");
        return $this->db->get('promociones')->result();
    }


    //Consulta que busca los datos de el ususario logueado
    public function BuscarUsuario(){
    $data['Franquicias']=$this->agregarcitaF_model->BuscarFranquicia();
    foreach ($data['Franquicias'] as $i => $Franquicias)

    $this->db->select('*');
    $this->db->from('usuarios');
    $this->db->where('Franquicias_IdFranquicias',$i);
    $this->db->where('Estatus', 'Activo');
    $query = $this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->NombreUsuario, ENT_QUOTES)] = htmlspecialchars($row->NombreUsuario, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

  
    //Consulta que busca la franquicia a la que pertenece el usuario logueado 
    public function BuscarFranquicia(){
     $this->db->select('*');
     $this->db->from('usuarios');
     $this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdFranquicias, ENT_QUOTES)] = htmlspecialchars($row->NombreFranquicia, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }
    public function BuscarDatosFranquicia(){
     $this->db->select('*');
     $this->db->from('franquicias');
     $this->db->join('usuarios','Franquicias_IdFranquicias=IdFranquicias','inner');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
         $query=$this->db->get();
        $res = $query->row();
         return $res;   
    }

     //Consulta que busca la franquicia a la que pertenece el usuario logueado 
     public function BuscarZona(){
     $this->db->select('*');
     $this->db->from('usuarios');
     $this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
     $this->db->join('zona','Zona_IdZona=IdZona','inner');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdZona, ENT_QUOTES)] = htmlspecialchars($row->NombreZona, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

     //Consulta que busca la franquicia a la que pertenece el usuario logueado 
     public function BuscarPagos(){
     $this->db->select('*');
     $this->db->from('exhibiciones');
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdExhibiciones, ENT_QUOTES)] = htmlspecialchars($row->NombreEx, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

    public function BuscarContra(){
    $this->db->select('Contrasenia');
    $this->db->from('usuarios');
    $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
    $query = $this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->Contrasenia, ENT_QUOTES)] = htmlspecialchars($row->Contrasenia, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

     public function BuscarModelo(){
     $this->db->select('*');
     $this->db->from('usuarios');
     $this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
     $this->db->join('modelo','Modelo_IdModelo=IdModelo','inner');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdModelo, ENT_QUOTES)] = htmlspecialchars($row->IdModelo, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }



 }


 
