<?php 
class AgregarcitaF extends CI_Controller
{
	
	function __construct()
	{
		parent::__construct();
		
		$this->load->model('agenda/franquiciatario/agregarcitaF_model');
		$this->load->library(array('session','form_validation'));
	}
	public function clientes(){
		if(isset($_GET['term'])){
			$result = $this->agregarcitaF_model->BuscarCliente($_GET['term']);
			if(count($result)>0){
				foreach ($result as $row) 
					$arr_result[] = array(
						'label' => $row->NombreCliente,
						'id'=> $row->IdClientes,
					);
					echo json_encode($arr_result);
				}
			}else {
				  echo "<script>alert('No se encontrarón los datos solicitados');</script>";
            // redirect('clientes/franquiciatario/clienteF','refresh');
			}
		}

	public function servicios(){
		if(isset($_GET['term'])){
			$result = $this->agregarcitaF_model->BuscarServicio($_GET['term']);
			$servicioG = $this->agregarcitaF_model->BuscarServicioG($_GET['term']);
			$promocionesI = $this->agregarcitaF_model->BuscarPromociones($_GET['term']);
			$promocionesF = $this->agregarcitaF_model->BuscarPromocion($_GET['term']);
				if(count($result)>0){
					foreach ($result as $row) 
					{
							$servicioA[] = array(
							'label' => $row->NombreServicio,
							'precio' => $row->PreciosServicio,
							'sesiones' => '',
							'identificador' => 'SA',
							'id' => $row->IdServiciosFranquicias,
							);
					}
				}else{
					// $servicioA[] ='';
					$servicioA[] = array();
				}
				if(count($servicioG)>0){
					foreach ($servicioG as $row) 
					{
						$arr_servicioG[] = array(
						'label' => $row->NombreServicio,
						'precio' => $row->PreciosServicio,
						'sesiones' => '',
						'identificador' => 'SG',
						'id' => $row->Codigo_Servicios,
						);
					}
				}else{
					// $arr_servicioG[] ='';
					$arr_servicioG[] = array();
				}
				if(count($promocionesI)>0){
					foreach ($promocionesI as $row) 
					{
						$arr_promocionesI[] = array(
						'label' => $row->NombrePromocion,
						'precio' => $row->Precio,
						'sesiones' => $row->FolioPromocion,
						'identificador' => 'PI',
						'id' => $row->IdPromociones,
						);
						
					}
				}else{ 
						// $arr_promocionesI[] ='';
						$arr_promocionesI[] = array();
					}
				if(count($promocionesF)>0){
					foreach ($promocionesF as $row) 
					{
						$arr_promocionesF[] = array(
						'label' => $row->NombrePromocion,
						'precio' => $row->Precio,
						'sesiones' => $row->FolioPromocion,
						'identificador' => 'PF',
						'id' => $row->IdPromociones,
						);
					}
					}else{ 
						// $arr_promocionesF[] ='';
						$arr_promocionesF[] = array();
					}
				// $resultado = $servicioA + $arr_servicioG;
				$resultado=array_merge($servicioA, $arr_servicioG, $arr_promocionesI, $arr_promocionesF);
				// $resultado2 = $resultado + $arr_promocionesI;
				$resultado2 = $servicioA + $arr_promocionesI;
				echo json_encode($resultado);
			
			}
	}
		public function serviciosG(){
		if(isset($_GET['term'])){
			$servicioG = $this->agregarcitaF_model->BuscarServicioG($_GET['term']);
				if(count($servicioG)>0){
				foreach ($servicioG as $row) 
					$arr_servicioG[] = array(
					'label' => $row->NombreServicio,
					'id' => $row->Codigo_Servicios,
				);
					echo json_encode($arr_servicioG);
				}
			}
		
}
//Promociones Institucionales
		public function promocionesIn(){
		if(isset($_GET['term'])){
			$result = $this->agregarcitaF_model->BuscarPromociones($_GET['term']);
				if(count($result)>0){
				foreach ($result as $row) 
					$arr_result[] = array(
					'label' => $row->NombrePromocion,
					'sesiones' => $row->FolioPromocion,
				);
					echo json_encode($arr_result);
				}
			}
	}
		//Promociones Franquicias
		public function promocionesF(){
		if(isset($_GET['term'])){
			$result = $this->agregarcitaF_model->BuscarPromocion($_GET['term']);
				if(count($result)>0){
				foreach ($result as $row) 
					$arr_result[] = array(
					'label' => $row->NombrePromocion,
					'sesiones' => $row->FolioPromocion,
				);
					echo json_encode($arr_result);
				}
			}
	}
}
